##############################################################################
#
#    GNU Health: The Free Health and Hospital Information System
#    Copyright (C) 2008-2022 Luis Falcon <falcon@gnuhealth.org>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

from trytond.pool import Pool
from . import health_ems
from . import sequences


def register():
    Pool.register(
        sequences.GnuHealthSequences,
        sequences.SupportRequestSequence,
        health_ems.Ambulance,
        health_ems.SupportRequest,
        health_ems.AmbulanceSupport,
        health_ems.AmbulanceHealthProfessional,
        health_ems.SupportRequestLog,
        module='health_ems', type_='model')

